==> contentsquare-2.0.0.tar.gz: example/simple_app/lib/src/screens/api_tests/widgets/webview/webview_screen.dart <==
import 'package:contentsquare_example/src/widgets/app_bar.dart';
import 'package:flutter/material.dart';

import '../../../../utils/navigate_and_monitor.dart';
import 'webviews/tracked/tracked_flutter_webview_screen.dart';
import 'webviews/tracked/tracked_in_app_webview_creen.dart';
import 'webviews/untracked/untracked_webview_screen.dart';

class WebViewScreen extends StatelessWidget {
  const WebViewScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Scaffold(
        appBar: appBar(title: 'WebViews'),
        body: Padding(
          padding: const EdgeInsets.only(top: 30.0),
          child: Column(
            children: [
              Padding(
                padding: EdgeInsets.symmetric(horizontal: 16),
                child: Text(
                  'Select which type of web view you want to test',
                  style: Theme.of(context).textTheme.headline6,
                ),
              ),
              SizedBox(height: 20),
              ListTile(
                title: Text('[Tracked] webview_flutter'),
                onTap: () => navigateAndMonitor(
                  context,
                  TrackedFlutterWebViewScreen(),
                ),
              ),
              ListTile(
                title: Text('[Tracked] flutter_inappwebview'),
                onTap: () => navigateAndMonitor(
                  context,
                  TrackedInAppWebViewScreen(),
                ),
              ),
              SizedBox(height: 10),
              ListTile(
                title: Text('[Untracked] WebView'),
                onTap: () => navigateAndMonitor(
                  context,
                  UntrackedWebViewScreen(),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> contentsquare-2.3.0.tar.gz: example/simple_app/lib/src/screens/api_tests/widgets/webview/webview_screen.dart <==
import 'package:contentsquare_example/src/widgets/app_bar.dart';
import 'package:flutter/material.dart';

import '../../../../utils/navigate_and_monitor.dart';
import 'webviews/tracked/tracked_flutter_webview_screen.dart';
import 'webviews/tracked/tracked_in_app_webview_creen.dart';
import 'webviews/untracked/untracked_webview_screen.dart';

class WebViewScreen extends StatelessWidget {
  const WebViewScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Scaffold(
        appBar: appBar(title: 'WebViews'),
        body: Padding(
          padding: const EdgeInsets.only(top: 30.0),
          child: Column(
            children: [
              Padding(
                padding: EdgeInsets.symmetric(horizontal: 16),
                child: Text(
                  'Select which type of web view you want to test',
                  style: Theme.of(context).textTheme.titleLarge,
                ),
              ),
              SizedBox(height: 20),
              ListTile(
                title: Text('[Tracked] webview_flutter'),
                onTap: () => navigateAndMonitor(
                  context,
                  TrackedFlutterWebViewScreen(),
                ),
              ),
              ListTile(
                title: Text('[Tracked] flutter_inappwebview'),
                onTap: () => navigateAndMonitor(
                  context,
                  TrackedInAppWebViewScreen(),
                ),
              ),
              SizedBox(height: 10),
              ListTile(
                title: Text('[Untracked] WebView'),
                onTap: () => navigateAndMonitor(
                  context,
                  UntrackedWebViewScreen(),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
